===========
Expressions
===========

This page gives an overview of all public polars expressions.

.. toctree::
   :maxdepth: 2

   aggregation
   array
   boolean
   categories
   columns
   computation
   functions
   modify_select
   meta
   miscellaneous
   strings
   struct
   timeseries
   window
